/* Decaf.java -- Go ahead... enable javascript. */

/* 
 * Copyright (C) 1996-98 Mark Boyns <boyns@sdsu.edu>
 *
 * This file is part of Muffin.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package muffin.filter;

import muffin.*;
import muffin.html.*;
import JP.ac.osaka_u.ender.util.regex.*;
import java.util.Hashtable;

public class Decaf implements FilterFactory
{
    final static String javaScriptAttrs[] =
    {
	"onblur",
	"onchange",
	"onclick",
	"onfocus",
	"onload",
	"onmouseover",
	"onmouseout",
	"onselect",
	"onsubmit",
	"onunload"
    };
					     
    FilterManager manager;
    Prefs prefs;
    DecafFrame frame = null;
    MessageArea messages = null;

    private RegExp javaScriptTags = null;

    public void setManager (FilterManager manager)
    {
	this.manager = manager;

	try
	{
	    javaScriptTags = new RegExp ("^a|input|body|form|area|select|frameset$");
	}
	catch (Exception e)
	{
	    e.printStackTrace ();
	}
    }
    
    public void setPrefs (Prefs prefs)
    {
	this.prefs = prefs;

	boolean o = prefs.getOverride ();
	prefs.setOverride (false);
	prefs.putBoolean ("Decaf.noJavaScript", true);
	prefs.putBoolean ("Decaf.noJava", false);
	prefs.putInteger ("Decaf.historySize", 500);
	prefs.setOverride (o);

	messages = new MessageArea (prefs.getInteger ("Decaf.historySize"));
    }

    public Prefs getPrefs ()
    {
	return prefs;
    }

    public void viewPrefs ()
    {
	if (frame == null)
	{
	    frame = new DecafFrame (prefs, this);
	}
	frame.setVisible (true);
    }
    
    public Filter createFilter ()
    {
	Filter f = new DecafFilter (this);
	f.setPrefs (prefs);
	return f;
    }

    public void shutdown ()
    {
	if (frame != null)
	{
	    frame.dispose ();
	}
    }

    public boolean isJavaScriptTag (String pattern)
    {
	MatchInfo info = javaScriptTags.match (pattern);
	return info != null;
    }

    void save ()
    {
	manager.save (this);
    }

    void process (String s)
    {
	messages.append (s);
    }
}

